==> opennebula_4.14.2.orig.tar.gz: opennebula-4.14.2/src/sunstone/public/app/utils/progress-bar.js <==
/* -------------------------------------------------------------------------- */
/* Copyright 2002-2015, OpenNebula Project, OpenNebula Systems                */
/*                                                                            */
/* Licensed under the Apache License, Version 2.0 (the "License"); you may    */
/* not use this file except in compliance with the License. You may obtain    */
/* a copy of the License at                                                   */
/*                                                                            */
/* http://www.apache.org/licenses/LICENSE-2.0                                 */
/*                                                                            */
/* Unless required by applicable law or agreed to in writing, software        */
/* distributed under the License is distributed on an "AS IS" BASIS,          */
/* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.   */
/* See the License for the specific language governing permissions and        */
/* limitations under the License.                                             */
/* -------------------------------------------------------------------------- */

define(function(require) {
  var _quotaBarHtml = function(usage, limit, info_str, not_html) {
    percentage = 0;

    if (limit > 0) {
      percentage = Math.floor((usage / limit) * 100);

      if (percentage > 100) {
        percentage = 100;
      }
    } else if (limit == 0 && usage > 0) {
      percentage = 100;
    }

    info_str = info_str || (usage + ' / ' + ((limit >= 0) ? limit : '-'));

    if (not_html) {
      return {
        "percentage": percentage,
        "str": info_str
      }
    } else {
      html = '<span class="progress-text right" style="font-size: 12px">' + info_str + '</span><br><div class="progress radius" style="height: 10px; margin-bottom:0px"><span class="meter" style="width: '          + percentage + '%"></div>';

      return html;
    }
  }

  return {
    'html': _quotaBarHtml
  }
})

==> opennebula_5.1.80.orig.tar.gz: opennebula-5.1.80/src/sunstone/public/app/utils/progress-bar.js <==
/* -------------------------------------------------------------------------- */
/* Copyright 2002-2016, OpenNebula Project, OpenNebula Systems                */
/*                                                                            */
/* Licensed under the Apache License, Version 2.0 (the "License"); you may    */
/* not use this file except in compliance with the License. You may obtain    */
/* a copy of the License at                                                   */
/*                                                                            */
/* http://www.apache.org/licenses/LICENSE-2.0                                 */
/*                                                                            */
/* Unless required by applicable law or agreed to in writing, software        */
/* distributed under the License is distributed on an "AS IS" BASIS,          */
/* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.   */
/* See the License for the specific language governing permissions and        */
/* limitations under the License.                                             */
/* -------------------------------------------------------------------------- */

define(function(require) {
  var _quotaBarHtml = function(usage, limit, info_str) {
    info_str = info_str || (usage + ' / ' + ((limit >= 0) ? limit : '-'));

    var value = "0";
    var max = "0";

    if (limit > 0 || (limit == 0 && usage > 0)){
      value = usage;
      max = limit;
    }

    html = '<span class="progress-text right" style="font-size: 12px">' + info_str + '</span>' + 
      '<br>' + 
      '<progress value="' + value + '" max="' + limit + '"></progress>';

    return html;
  }

  return {
    'html': _quotaBarHtml
  }
})
